@@ -358,7 +358,7 @@ class CatchallPredicate:
 
     def __init__(self, targets, config):
         def _adapt(obj) -> CatchallTarget:
-            if type(obj) is CatchallTarget:
+            if isinstance(obj, CatchallTarget):
                 return obj
             if type(obj) not in (tuple, dict, list):
                 return CatchallTarget(obj)
@@ -432,7 +432,6 @@ class CatchallPredicate:
             if query.whereclause is None:
                 # no implicit/context filters
                 getter = _get_by_pkey(pkey)
-                print (str(query.whereclause))
             else:
                 filters = map(
                     lambda x: x[0]==x[1], 
